@@ -64,10 +64,9 @@ checkBinaries <- function() {
   all(ctrdata:::checkBinary())
 }
 
-
 checkInternet <- function() {
   tmp <- try(
-    httr::HEAD("https://httpbin.org/anything", httr::timeout(10L)),
+    curl::nslookup("r-project.org"),
     silent = TRUE
   )
 
@@ -75,7 +74,6 @@ checkInternet <- function() {
   out
 }
 
-
 checkSqlite <- function() {
   tmp <- try(nodbi::src_sqlite(), silent = TRUE)
   out <- inherits(tmp, c("src_sqlite", "docdb_src"))
